searchData={"items":[{"type":"module","title":"Exrpc","doc":"Simple Elixir RPC without Erlang distribution.\n\nTo set up, you need to start `Exrpc.Server` on the server side and `Exrpc.Client` on the client side.\n\nStart `Exrpc.Server` with a list of modules and functions you want to expose:\n\n```elixir\ndefmodule ServerSideModule do\n  def hello(name), do: \"Hello \"   name\nend\n\n# start link or add child spec to your supervisor\nExrpc.Server.start_link(name: :my_server, port: 5670, mfa_list: [&ServerSideModule.hello/1])\n```\n\nStart `Exrpc.Client` with the address of the server:\n\n```elixir\n# start link or add child spec to your supervisor\nExrpc.Client.start_link(name: :my_client, host: \"localhost\", port: 5670)\n```","ref":"Exrpc.html"},{"type":"function","title":"Exrpc.call/5","doc":"Calls a remote function.\n\n    iex> Exrpc.call(:my_client, ServerSideModule, :hello, [\"world\"])\n    \"Hello world\"","ref":"Exrpc.html#call/5"},{"type":"function","title":"Exrpc.mfa_list/1","doc":"List available remote functions.\n\n    iex> Exrpc.mfa_list(:my_client)\n    [{ServerSideModule, :hello, 1}]","ref":"Exrpc.html#mfa_list/1"},{"type":"module","title":"Exrpc.Codec","doc":"Binary protocol for Exrpc.","ref":"Exrpc.Codec.html"},{"type":"module","title":"Examples - Exrpc.Codec","doc":"iex> Exrpc.Codec.encode(:mfa_list)\n    \"?\"\n    iex> Exrpc.Codec.decode(\"?\")\n    :mfa_list\n\n    iex> bin = Exrpc.Codec.encode([1, [1, 2, 3]])\n     >\n    iex> Exrpc.Codec.decode(bin)\n    [1, [1, 2, 3]]\n\n    iex> bin = Exrpc.Codec.encode({:goodrpc, \"hello\"})\n     >\n    iex> Exrpc.Codec.decode(bin)\n    {:goodrpc, \"hello\"}\n\n    iex> Exrpc.Codec.encode({:badrpc, :invalid_request})\n     >\n    iex> Exrpc.Codec.decode( >)\n    {:badrpc, :invalid_request}\n\n    iex> bin = Exrpc.Codec.encode({:badrpc, %ArgumentError{message: \"ugh\"}})\n     >\n    iex> Exrpc.Codec.decode(bin)\n    {:badrpc, %ArgumentError{message: \"ugh\"}}","ref":"Exrpc.Codec.html#module-examples"},{"type":"function","title":"Exrpc.Codec.decode/1","doc":"","ref":"Exrpc.Codec.html#decode/1"},{"type":"function","title":"Exrpc.Codec.encode/1","doc":"","ref":"Exrpc.Codec.html#encode/1"},{"type":"module","title":"Exrpc.MFA","doc":"This module provides functions to validate and create `{module, function, arity}` tuple.","ref":"Exrpc.MFA.html"},{"type":"function","title":"Exrpc.MFA.callable?/1","doc":"Checks if the given `{module, function, arity}` or `&module.function/arity` is callable.","ref":"Exrpc.MFA.html#callable?/1"},{"type":"function","title":"Examples - Exrpc.MFA.callable?/1","doc":"iex> Exrpc.MFA.callable?({Enum, :into, 2})\n    true\n    iex> Exrpc.MFA.callable?(&Enum.into/2)\n    true\n    iex> Exrpc.MFA.callable?(&Enum.into/255)\n    false\n    iex> Exrpc.MFA.callable?(&Enum.get_rich_quick/1)\n    false","ref":"Exrpc.MFA.html#callable?/1-examples"},{"type":"function","title":"Exrpc.MFA.list/1","doc":"Returns list of mfa tuples from the given module.","ref":"Exrpc.MFA.html#list/1"},{"type":"function","title":"Examples - Exrpc.MFA.list/1","doc":"iex> defmodule Foo do\n    iex>   def bar(), do: :ok\n    iex>   def baz(), do: qux()\n    iex>   defp qux(), do: :ok\n    iex> end\n    iex> Exrpc.MFA.list(Foo)\n    [{Foo, :bar, 0}, {Foo, :baz, 0}]\n    iex> Exrpc.MFA.list(NotAModule)\n    []","ref":"Exrpc.MFA.html#list/1-examples"},{"type":"function","title":"Exrpc.MFA.tuple/1","doc":"Creates `{module, function, arity}` tuple from the given `&module.function/arity` or `{module, function, arity}`.","ref":"Exrpc.MFA.html#tuple/1"},{"type":"function","title":"Examples - Exrpc.MFA.tuple/1","doc":"iex> Exrpc.MFA.tuple({Enum, :into, 2})\n    {Enum, :into, 2}\n    iex> Exrpc.MFA.tuple(&Enum.into/2)\n    {Enum, :into, 2}","ref":"Exrpc.MFA.html#tuple/1-examples"},{"type":"function","title":"Exrpc.MFA.valid?/1","doc":"Checks if the given `{module, function, arity}` or `&module.function/arity` is valid.","ref":"Exrpc.MFA.html#valid?/1"},{"type":"function","title":"Examples - Exrpc.MFA.valid?/1","doc":"iex> Exrpc.MFA.valid?({Enum, :into, 2})\n    true\n    iex> Exrpc.MFA.valid?(&Enum.into/2)\n    true\n    iex> Exrpc.MFA.valid?(&Enum.into/255)\n    true\n    iex> Exrpc.MFA.valid?(&Enum.get_rich_quick/1)\n    true\n    iex> Exrpc.MFA.valid?(Enum)\n    false","ref":"Exrpc.MFA.html#valid?/1-examples"},{"type":"module","title":"Exrpc.MFALookup","doc":"Function allowlist and lookup table.\n\nUnlike `:rpc`, we don't transmit module and function names over the wire.\nEach function is assigned a unique integer ID, and the client sends the ID based on this lookup table.\n\n  # Instantiate a new lookup table:\n  iex> Exrpc.MFALookup.create([])\n  {:error, :empty_list}\n  iex> {:ok, lookup} = Exrpc.MFALookup.create([{Greeter, :hello, 1}, {Greeter, :goodbye, 1}, {Adder, :add, 2}])\n  {:ok, lookup}\n  # Route to ID and vice-versa:\n  iex> Exrpc.MFALookup.mfa_to_id(lookup, {Greeter, :hello, 1})\n  0\n  iex> Exrpc.MFALookup.mfa_to_id(lookup, {Greeter, :goodbye, 1})\n  1\n  iex> Exrpc.MFALookup.mfa_to_id(lookup, {Adder, :add, 2})\n  2\n  iex> Exrpc.MFALookup.mfa_to_id(lookup, {Greeter, :howdy, 1})\n  nil\n  iex> Exrpc.MFALookup.id_to_mfa(lookup, 0)\n  {Greeter, :hello, 1}\n  iex> Exrpc.MFALookup.id_to_mfa(lookup, 1)\n  {Greeter, :goodbye, 1}\n  iex> Exrpc.MFALookup.id_to_mfa(lookup, 2)\n  {Adder, :add, 2}\n  iex> Exrpc.MFALookup.id_to_mfa(lookup, 3)\n  nil\n  # Convert lookup table to list (for transmitting to clients):\n  iex> Exrpc.MFALookup.to_list(lookup)\n  [{Greeter, :hello, 1}, {Greeter, :goodbye, 1}, {Adder, :add, 2}]","ref":"Exrpc.MFALookup.html"},{"type":"function","title":"Exrpc.MFALookup.create/1","doc":"","ref":"Exrpc.MFALookup.html#create/1"},{"type":"function","title":"Exrpc.MFALookup.id_to_mfa/2","doc":"","ref":"Exrpc.MFALookup.html#id_to_mfa/2"},{"type":"function","title":"Exrpc.MFALookup.mfa_to_id/2","doc":"","ref":"Exrpc.MFALookup.html#mfa_to_id/2"},{"type":"function","title":"Exrpc.MFALookup.to_list/1","doc":"","ref":"Exrpc.MFALookup.html#to_list/1"},{"type":"type","title":"Exrpc.MFALookup.function_name/0","doc":"","ref":"Exrpc.MFALookup.html#t:function_name/0"},{"type":"type","title":"Exrpc.MFALookup.id/0","doc":"","ref":"Exrpc.MFALookup.html#t:id/0"},{"type":"type","title":"Exrpc.MFALookup.t/0","doc":"","ref":"Exrpc.MFALookup.html#t:t/0"}],"content_type":"text/markdown"}